@@ -2,6 +2,7 @@ package XML::RSS::FromHTML::Test;
 use base XML::RSS::FromHTML;
 use strict;
 use FindBin;
+use File::Path;
 
 __PACKAGE__->mk_accessors(qw(
 	prop01
@@ -11,8 +12,12 @@ __PACKAGE__->mk_accessors(qw(
 sub init {
 	my $self = shift;
 	$self->name('Test');
-	$self->cacheDir($FindBin::RealBin.'/cache');
-	$self->feedDir($FindBin::RealBin.'/feed');
+    my $cachedir = '/tmp/XML-RSS-FromHTML/cache';
+    my $feeddir = '/tmp/XML::RSS::FromHTML/feed';
+    mkpath $cachedir, 0 if !-d $cachedir;
+    mkpath $feeddir, 0 if !-d $feeddir;
+	$self->cacheDir($cachedir);
+	$self->feedDir($feeddir);
 	$self->prop01('foo');
 	$self->prop02('bar');
 	return 1;
@@ -57,4 +62,10 @@ sub defineRSS {
 	return 1;
 }
 
+sub DESTROY {
+    my $self = shift;
+    rmtree $self->cacheDir, 0;
+    rmtree $self->feedDir, 0;
+}
+
 1;
